'''处理字符串相关的方法集合'''
import re
import enchant


class String(str):
    @staticmethod
    def cleanemoji(content):
        '''过滤表情符号'''
        pattern = re.compile(u'['u'\U0001F300-\U0001F64F' u'\U0001F680-\U0001F6FF' u'\u2600-\u2B55 \U00010000-\U0010ffff]+')
        return  re.sub(pattern, '', content)



    def split(self,pattern):
        '''正则分割字符串'''
        return re.split(pattern,self)



    @staticmethod
    def is_en_word(word):
        '''判断是否是正确单词'''
        d = enchant.Dict("en_US")
        return d.check(word)











from setuptools import setup,find_packages
setup(
    name='py-detail-tools',
    version='1.0.1',
    author_email='xiaoyaojianxians@163.com',
    maintainer='robin',
    maintainer_email='xiaoyaojianxians@163.com',
    url='https://pypi.org/manage/account/',
    description='这是一个处理字符串小工具',
    long_description='这是一个处理字符串小工具,后续会不断更新叠加各种字符串处理功能',
    keywords=['字符串','字符处理','正则过滤表情字符','表情字符'],
    packages=find_packages(),
    install_requires=['pyenchant']

)